@@ -3,9 +3,8 @@ import inspect
 
 from aiohttp import web as aio_web
 
-from bolinette import env, jwt, bcrypt, db, services
+from bolinette import env, network, bcrypt, db, services, web, ws
 from bolinette.commands import commands
-from bolinette.routing import web, resources
 
 
 class Bolinette:
@@ -13,17 +12,17 @@ class Bolinette:
         env.init_app(profile=profile, overrides=overrides)
         db.engine.init_app()
         services.init_services()
-        jwt.init_app()
+        network.jwt.init_app()
         bcrypt.init_app()
-        web.init_app()
-        resources.init_app()
+        web.resources.init_app()
+        ws.resources.init_app()
 
     def run(self):
-        aio_web.run_app(web.app)
+        aio_web.run_app(web.resources.app)
 
     @property
     def app(self):
-        return web.app
+        return web.resources.app
 
     def run_command(self, name, **kwargs):
         if name in commands.commands:
