@@ -3,7 +3,7 @@ from bolinette.commands import command
 
 
 @command('init_db')
-async def init_db(*, run_seeders=False, **_):
+async def init_db(*, run_seeders=True, **_):
     await db.engine.drop_all()
     await db.engine.create_all()
     if run_seeders:
